// src/Product.js

import React, {useState} from 'react';
import { Card, CardContent, CardMedia, Typography, Dialog, DialogContent, Button } from '@mui/material';
import { styled } from '@mui/system';

const AnimatedCard = styled(Card)({
  transition: 'transform 0.4s cubic-bezier(0.250, 0.460, 0.450, 0.940)',
  '&:hover': {
    transform: 'scale(1.05)',
    boxShadow: '0px 10px 10px rgba(0, 0, 0, 0.10)',
  },
});

const Product = ({ imageUrl, price }) => {
  const [open, setOpen] = useState(false);

  const handleOpen = () => {
    setOpen(true);
  };

  const handleClose = () => {
    setOpen(false);
  };

  const handleAddToCart = () => {
    // You can implement the add to cart functionality here
    alert('Product added to cart');
    handleClose(); // Close the dialog after adding to cart (optional)
  };

  return (
    <>
    <AnimatedCard sx={{ maxWidth: 345, cursor: 'pointer' }} onClick={handleOpen}>
      <CardMedia
        component="img"
        height="280"
        image={imageUrl}
        alt="Product Image"
      />
      <CardContent>
        <Typography variant="h5" color='secondary' component="div">
          Price: ${price}
        </Typography>
      </CardContent>
    </AnimatedCard>
    <Dialog open={open} onClose={handleClose}>
      <DialogContent>
        <img src={imageUrl} alt="Product Image" style={{ maxWidth: '100%' }} />
      </DialogContent>
      <Button variant="contained" color="primary" onClick={handleAddToCart} style={{ marginTop: 16 }}>
            Add to Cart
      </Button>
    </Dialog>
    </>
  );
};

export default Product;
